
clear
set mem 800m
set more off
set linesize 165
set maxvar 10000


/**
 PURPOSE: Describe and tabulate our panel data file derived from the
          RAND data file and run regressions involving health status,
	  preventive-health measures, and CESD index.
 
 LAST MODIFIED: JAN 23, Matt Noto
**/



/** 
 GLOBAL VARIABLES
 **/

** "qui" - do not give regression output and do not give output to (2) and (3) below
** "noi" - give all regression output to each regression as well as (2) and (3) results and tables
global qui = "noi"
if ("`1'" == "qui") {
 global qui = "qui"
}



/**
 **
 prepare CAMS data
 **
 **/
clear
use cams
gen long hhidpn = hhid * 1000 + pn
drop pn
** '01 -> '00
** '03 -> '02
** '05 -> '04
replace year = year - 1
egen rowmiss = rownonmiss(B_*)
drop if rowmiss == 0
drop rowmiss 
bys hhid year: gen size = _N
tab size, missing
sort hhidpn year
save /tmp/cams_hhidpn.dta, replace



/**
 This is the "panel" data set that is created by prepareSample.do and
it contains all of the sample restrictions used in our basic regressions
 **/
use rand_panel_restricted






**
** hhidpn is "hhid" + "pn", where "pn" is 3-digit number
**
gen hhid = floor(hhidpn / 1000)
bys hhid wave: gen size = _N
tab size, missing


sort hhidpn year
capture drop _merge
merge hhidpn year using /tmp/cams_hhidpn.dta, uniqusing update
tab year _merge
drop if _merge == 2 


bys year: count if B_mortgage < .
bys year: count if B_mortgage < . & rage >= 50 & isretired == 1

summ hh_tot_inc

preserve
keep if B_electricity < .
sort hhid year hhidpn
list hhid year hhidpn B_electricity B_water B_lease B_mortgage in 1/200
restore


**
* update cams data
**
do cams.do

bys year: summ log_h log_c log_c_nd


** count number of individuals with consumption data
preserve
collapse (mean) B_mortgage, by(hhid)
count
count if B_mortgage < .
restore




capture drop numwaves
bys hhidpn: gen numwaves = _N
bys hhidpn: replace myn = _n
tab numwaves if myn == 1




**
* SUMMARIES
**
summ hh_tot_inc log_inc_perm dummy_inc_perm
tab wave
bys wave: summ rcesd rnotdep rwhappy rage rageSquared single isfemale isblack spouse_working resp_disabled spouse_disabled 
bys wave: summ rhibpe rdi* rcanc* rlung* rhear* rstro* rpsy* rarthr* rany* rnumdis
bys wave: summ rnumdis rnumDisWgt snumdis snumDisWgt hnumdis hnumDisWgt
bys wave: summ rcholst rflusht rbreast rmammog rpapsm rprost rseatBelts rfracPrev 



**
* DROP if dummy on
* AND turn off dummy
**
summ inc_perm, det
drop if inc_perm < r(p1)
replace log_inc_perm = log(inc_perm)
replace dummy_inc_perm = 0

sort hhidpn wave
by hhidpn: assert(log_inc_perm[1] == log_inc_perm[_N])



**********
* sample numbers
*  0         - married+single, all waves, all over 50, is retired, has health insurance
*  1         - add in those w/o health insurance to 0
*  2         - add in those in labor forace to 0
*  3         - drop (likely) home-makers
*  4         - limit 0 to those who are always single
*  5         - limit 0 to those who are currently single
*  6         - limit 0 to those who are +65 (and spouse +65)
*  7-8  (deprecated)
*  9         - (social security + pension income) > 50% of perm inc
* 10         -                  "                 > 75% of perm inc
* 11         -                  "                 > 90% of perm inc
* 12         - limit 0 to sample with seat belt data
* 13         - limit 0 to sample with seat belt data and preventive care data
* 14         - limit 0 to HRS sample

global reg = "areg"
global options = " absorb(hhidpn) cluster(hhidpn) "
gen wgt = 1


local sample = 0
foreach var of varlist isretired {
 capture drop `var'_not_retired 
 capture drop `var'_sum
 gen `var'_not_retired = (`var' != 1 | hasHealthInsurance != 1)
 gsort hhidpn -wave
 by hhidpn: gen `var'_sum = sum(`var'_not_retired)
 gen sample`sample' = (`var'_sum == 0 & rage >= 50)
 local sample = `sample' + 1 
}
do no_singletons 0

*sort hhidpn wave
*list hhidpn wave isretired hasHealthInsurance sample10 sample0 sample5 in 1/1000




** 
* R4: "It would be nice to see the fraction of potential respondents
*  by initial age in sample 
**
preserve
drop if isretired == .
sort hhidpn wave
replace rage = 50 if rage <= 50
replace rage = 85 if rage  > 85
by hhidpn: gen init_age = rage[1]
capture drop N
gen N = 1
collapse (mean) sample0 (sum) N, by(init_age)
sort init_age
list init_age sample0
restore





**
* never drops h.i. & currently has health insurance
** 


**
* add in non-h.i.
**
gen sample1 = (isretired == 1 & rage >= 50)
do no_singletons 1

**
* add in ilf's
** 
gen sample2 = (rage >= 50 & loses_hi == 0 & hasHealthInsurance == 1)
do no_singletons 2


**
* rsayret == 3 => "not applicable" => likely homemaker
* spouse NOT in labor force
gen sample3 = (rage >= 50 & isretired == 1 & (spouse_retired == 1 | single == 1) & loses_hi == 0 & hasHealthInsurance == 1)
do no_singletons 3



**
* always single
**
gen sample4 = (sample0 & alwaysSingle == 1)
capture drop alwaysSingle_temp
bys hhidpn: egen alwaysSingle_temp = sum(sample0 & single == 1)
bys hhidpn: egen sample0_temp = sum(sample0)
replace alwaysSingle = (alwaysSingle_temp == sample0_temp)
do no_singletons 4


**
* single
gen sample5 = (sample0 & single == 1)
do no_singletons 5




**
* over 65 + spouse over 65
**gen sample6 = (rage >= 65 & isretired == 1 & (sage >= 65 | single == 1))
gen sample6 = (rage >= 65)
do no_singletons 6


**
* over 65 + not working + has h.i.
**
gen sample15 = (rage >= 65 & isretired == 1 & hasHealthInsurance == 1)
do no_singletons 15


**
* always single; over 65; over 65 + retired
**
gen sample16 = (sample6  & alwaysSingle == 1)
do no_singletons 16

gen sample17 = (sample15 & alwaysSingle == 1)
do no_singletons 17




**
* TODO(!)
*  allow re-entry after N waves
**
sort hhidpn wave
gen isretired_nomiss = (isretired == 1 & hasHealthInsurance == 1)
replace isretired_nomiss = 0 if isretired_nomiss >= .
by hhidpn: gen retired_sum = sum(isretired_nomiss)
by hhidpn: gen health_nomiss = sum(isretired_nomiss)
gen sample7 = (retired_sum > 0 & rage >= 50)
do no_singletons 7

gen sample8 = (sample0 & ishomemaker == 0)
do no_singletons 8


** SS + pension fraction > 50%
gen sample9 = sample0 & frac_ss_pen > 0.50
do no_singletons 9
** SS + pension fraction > 75%
gen sample10 = sample0 & frac_ss_pen > 0.75
do no_singletons 10
** SS + pension fraction > 90%
gen sample11 = sample0 & frac_ss_pen > 0.90
do no_singletons 11

gen sample12 = sample0 & rseatBelts < .
do no_singletons 12

gen sample13 = sample0 & rseatBelts < . & rfracPrevExt < . 
do no_singletons 13


**
* HRS cohort
**
tab rcohort, missing
gen sample14 = sample0 & rcohort == 3




** SS + pension fraction > 50%
gen sample18 = sample0 & frac_ss_pen2 > 0.50
do no_singletons 18
** SS + pension fraction > 75%
gen sample19 = sample0 & frac_ss_pen2 > 0.75
do no_singletons 19

** SS + pension fraction > 50%
gen sample20 = sample0 & frac_ss_pen > 0.50 & has_dc == 0
do no_singletons 20
** SS + pension fraction > 75%
gen sample21 = sample0 & frac_ss_pen > 0.75 & has_dc == 0
do no_singletons 21

** SS + pension fraction > 50%
gen sample22 = sample15 & frac_ss_pen > 0.50 & has_dc == 0
do no_singletons 22
** SS + pension fraction > 75%
gen sample23 = sample15 & frac_ss_pen > 0.75 & has_dc == 0
do no_singletons 23



global max_sample = 22


summ raedyrs, detail
tab alwaysHasInsurance
tab noUnder65 
tab alwaysSingle
tab wave isretired, missing
tab wave isretired if rage > 65, missing

xi i.wave



replace rnhmliv = 1 if rnrsnit > 0 & rnrsnit < .
sort hhidpn wave
by hhidpn: replace rnhmliv = 1 if wave == 2 & rnhmliv[_n + 1] == 1
by hhidpn: replace rnhmliv = 1 if wave == 1 & rnhmliv[_n + 1] == 1
replace rnhmliv = 0 if missing(rnhmliv)
**bys wave: summ rnhmliv


**
** MAKE GRAPHS
**
** do b_graph

**
* get final sample
**
keep if rwhappy < . 
keep if log_inc_perm < .
keep if single < .
keep if rage < .
keep if isretired < .
keep if hh_size < .
keep if rnumdis < .



**
* Fraction of >= 50 
**
count if rage >= 50 & hasHealthInsurance == 1
local denom = r(N)
count if rage >= 50 & hasHealthInsurance == 1 & isretired == 1
local numer = r(N)
local frac = `numer' / `denom'
di "frac: `frac' ..."

count if rage >= 65 & hasHealthInsurance == 1
local denom = r(N)
count if rage >= 65 & hasHealthInsurance == 1 & isretired == 1
local numer = r(N)
local frac = `numer' / `denom'
di "frac: `frac' ..."

saveold rand_hrs_final.dta, replace

exit
