
clear
set mem 1000m
set more off
set linesize 200
set maxvar 30000






/**
 PURPOSE: Describe and tabulate RAND data file and create panel data
          set from RAND data file.
 
 LAST MODIFIED: JAN 15, Matt Noto
**/




/**
  "rndhrs_f" is the data file from the RAND, which merges the HRS and
AHEAD waves into a single data set.

  It contains all of the "waves" merged into one data file and it is
in a "wide" format -- meaning that for a given individual there is
only one person record in the entire data set, and that record
contains the values for every wave that the individual participated
in.  For example, for an individual present in all seven waves and
collecting retirement income in all seven waves, the level of
retirement income reported in each wave would be in the variables
r1ipena, r2ipena, ... , r7ipena.  This is what I mean by "wide" format.

  Each "wide" person record contains a unique identifier (household
number + person number), and the household number embedded in the
identifier is identical across waves and represent whether individuals
belong to the same household.  Most households contain one or two
members.

  For households with two members, there is some duplication of data
in the RAND file.  Each member contains one "wide" record (see above),
but that record contains information both about the respondent and the
spouse.  The spouse also has his/her own record, which also contains
information about both household members.  For example, assume person
A and person B are in the same household and they are each other's
spouse.  Then the field s2ipena for person A (the retirement income
for the spouse of person A) is the *same* as r2ipena for person B
(the retirement income of person B, who is person A's spouse).

 FULL DATA DOCUMENTATION IS HERE:
   http://web.mit.edu/noto/Public/stateDependentUtility/randDocumentation.pdf

**/
use rndhrs_f




**keep if hhidpn == 10106010 | hhidpn == 10106020
/**
keep r3iearn r3ipena s3iearn s3ipena hhidpn s3hhidpn
keep if hhidpn > 10000000 & hhidpn < 10200000
sort hhidpn
list
count
count if s3iearn >= .
** exit
**/








********
* CHECK STRUCTURE OF DATA SET
*
/**
 This code just gives a cursory glance at the data set to confirm that
the "symmetry" discussed above appears to generally hold.  This could
be updated to do more formal tests of symmetry using "assert"
statements
**/
*
* confirm:
*  - record is individual-level
*  - within each household, there are usually 2 individual records
*  - each individual's "spouse" record data should match the spouse's
*    own respondent data
/**
gen hhid_num = real(hhid)
gen pid_num  = hhidpn - 1000*hhid_num
bys hhid_num: gen size = _N
tab size
keep if size == 2
list hhid_num pid_num r1cesd s1cesd r2cesd s2cesd r3cesd s3cesd in 1/20
**/


sort rahhidpn
merge rahhidpn using ../hrs/h04/h04, uniqusing uniqmaster
tab _merge
drop if _merge == 2
drop _merge

sort rahhidpn
merge rahhidpn using ../hrs/h02/h02, uniqusing uniqmaster
tab _merge
drop if _merge == 2
drop _merge

sort rahhidpn
merge rahhidpn using ../hrs/h00/h00, uniqusing uniqmaster
tab _merge
drop if _merge == 2
drop _merge

sort rahhidpn
merge rahhidpn using ../hrs/h98/h98, uniqusing uniqmaster
tab _merge
drop if _merge == 2
drop _merge

sort rahhidpn
merge rahhidpn using ../hrs/h96/h96, uniqusing uniqmaster
tab _merge
drop if _merge == 2
drop _merge

sort rahhidpn
merge rahhidpn using ../hrs/h95/h95, uniqusing uniqmaster
tab _merge
drop if _merge == 2
drop _merge

sort rahhidpn
merge rahhidpn using ../hrs/h94/h94, uniqusing uniqmaster
tab _merge
drop if _merge == 2
drop _merge

sort rahhidpn
merge rahhidpn using ../hrs/h92/h92, uniqusing uniqmaster
tab _merge
drop if _merge == 2
drop _merge






**
* year   wave
* 92     1
* 93/94  2
* 95/96  3
* 98     4
* 00     5
* 02     6
* 04     7
**
assert( !(seatBelts95 < . & seatBelts96 < .) )

rename  seatBelts95 rseatBelts3
replace rseatBelts3 = seatBelts96 if rseatBelts3 >= .
drop seatBelts96

rename  seatBelts98 rseatBelts4
rename  seatBelts00 rseatBelts5


**
* pension_dc
**
assert( !(pension_dc3a < . & pension_dc3b < .))
rename pension_dc3a pension_dc3
replace pension_dc3 = pension_dc3b if pension_dc3 >= .
drop pension_dc3b





rename  mcareHMO95 mcareHMO3
replace mcareHMO3 = mcareHMO96 if mcareHMO3 >= .
drop mcareHMO96

rename  mcareHMO98 mcareHMO4
rename  mcareHMO00 mcareHMO5
rename  mcareHMO02 mcareHMO6
rename  mcareHMO04 mcareHMO7



/**
  A QUESTION: (WEIGHTS)

  I am assuming that the weight variable r`n'wtresp (the person-level
weight) is the appropriate weight to use and also that the weight can
be used as an analytical weight.

  (see page 81 in full data documentaiton above)
**/




/**
  A NOTE ON THE "WAVES" IN THE RAND
 
  The rand maps the HRS and AHEAD surveys into a "wave" number as
follows:
- Wave 1 is from 1992 (V 1.01)
- Wave 2 is from 1994 (V1.0) data for the HRS cohort, and 1993 (V2.1) for the
  AHEAD cohort
- Wave 3 is from 1996 (V4.0) data for the HRS cohort, and 1995 (V2.0) for the
  AHEAD cohort
- Wave 4 is from 1998 (V2.3)
- Wave 5 is from 2000 (V1.0)
- Wave 6 is from 2002 (V1.0)
- Wave 7 is from 2004 (ER1.0) 
**/





/**
 PROXY TABLES FOR ENTIRE SAMPLE (i.e. FULL SAMPLE OF RETIRED AND NON-RETIRED)

 NOTE: missing values seem to mostly come from individuals who were
not surveyed in earlier or later waves (e.g. because they arrived
later or died during survey.

 VERIFIED: UNWEIGHTED SAMPLE SIZE IS 30,207 FOR EVERY WAVE
**/
forvalues n = 1(1)7 {

 ** RESPONDENT PROXY STATUS IN WAVE `n'
 **  NOTE: weight set to 0 if not in wave (page 79 in data doc)

 tab r`n'proxy [aw=r`n'wtresp], missing
 tab r`n'proxy, missing

}






/**
 HEALTH STATUS VARIABLE TABULATIONS 
  (FOR "FULL" SAMPLE OF RETIRED/NON-RETIRED)

 DISEASES:
  high blod pressure
  diabetes
  cancer
  lung disease
  heart disease or heart attack
  stroke
  psychiactric problems (emotional, nervous)
  arthritis
  back pain

 BIG TO-DO!!!
  MAKE SURE THESE VARIABLES ARE "ABSORBING" STATE!!
  RAND DOCUMENTATION SAYS THIS MIGHT NOT BE THE CASE
  THEY HAVE THEIR OWN DATA QUALITY FLAGS FOR THIS

 NOTE: 
  NO Glaucoma since it only appears in a few waves
**/
forvalues n = 2(2)6 {
**
** HEALTH STATUS VARIABLES FOR WAVE `n'
tab r`n'hibpe  [aw=r`n'wtresp], missing
tab r`n'diabe  [aw=r`n'wtresp] , missing
tab r`n'cancre [aw=r`n'wtresp], missing
tab r`n'lunge  [aw=r`n'wtresp] , missing
tab r`n'hearte [aw=r`n'wtresp], missing
tab r`n'stroke [aw=r`n'wtresp], missing
tab r`n'psyche [aw=r`n'wtresp], missing
tab r`n'arthre [aw=r`n'wtresp], missing
tab r`n'back   [aw=r`n'wtresp]  , missing
*tab r`n'ulcer [aw=r`n'wtresp], missing
}












/**
  TABULATE WAGE/PENSION/ANNUITY INCOME TO FIND NATURAL 'CUT-OFF' FOR
RETIRED INDIVIDUALS WHO STILL HAVE WAGE INCOME"
 (I choose $5000 as cut-off for now)

 The code below tabulates various measures of income for wave 2 and
wave 6 to investigate what the right income cut-off should be.  We
want to use an income cut-off in addition to the self-reported
retirement status because there is a small fraction of individuals who
self-report high wage/salary income and that they are retired.

variable definitions:

 r`n'ipena: respondent pension/retirement/annuity income in wave `n'
 s`n'ipena: spouse pension/retirement/annuity income in wave `n'

 r`n'earn:  respondent wage/salary earnings in wave `n'
 s`n'earn:  spouse wage/salary earnings in wave `n'

 r`n'issdi: respondent SSI and SSDI income in wave `n'
 s`n'issdi: spouse SSI and SSDI income in wave `n'

 r`n'isret: respondent Social Security Retirement income in wave `n'
 s`n'isret: spouse Social Security Retirement income in wave `n'

 r`n'sayret: respondent self-reported retirement status in wave `n'
 s`n'sayret: spouse self-reported retirement status in wave `n'
   1 = retired
   3 = N/A (e.g. home-maker or never in labor force)
   . = missing
**
**/

** BEGIN LOOP (LOOP DOES WAVE 2 AND WAVE 6)
forvalues n = 2(4)6 { 

di "PENSION AND ANNUITY INCOME IN WAVE `n' " 
summ r`n'ipena [aw=r`n'wtresp], detail 

di "DEFINE RETIREMENT AS ONLY RESPONDENT SAYS RETIRED IN WAVE `n'"
summ r`n'ipena [aw=r`n'wtresp] if (r`n'sayret == 1), detail

di "DEFINE RETIREMENT AS RESPONDENT RETIRED OR NEVER IN LABOR FORACE *AND* SPOUSE RETIRED OR NEVER IN LABOR FORCE (DEMANDING DEF'N)"
summ r`n'ipena [aw=r`n'wtresp] if (r`n'sayret == 1 | r`n'sayret == 3) & (s`n'sayret == . | s`n'sayret == 1 | s`n'sayret == 3), detail

di "WAGE AND SALARY EARNINGS IN WAVE `n' FOR RETIRED INDIVIDUALS"
*summ r`n'iearn [aw=r`n'wtresp] , detail
*summ r`n'iearn [aw=r`n'wtresp] if r`n'sayret != 1 & s`n'sayret != 1, detail
*summ r`n'iearn [aw=r`n'wtresp] if (r`n'sayret == 1 | r`n'sayret == 3), detail
*summ r`n'iearn [aw=r`n'wtresp] if (r`n'sayret == 1), detail
*summ r`n'iearn [aw=r`n'wtresp] if (r`n'sayret == 1) & (s`n'sayret == . | s`n'sayret == 1 | s`n'sayret == 3), detail
summ r`n'iearn [aw=r`n'wtresp] if (r`n'sayret == 1 | r`n'sayret == 3) & (s`n'sayret == . | s`n'sayret == 1 | s`n'sayret == 3), detail

di "SSDI AND SSI INCOME IN WAVE `n'"
summ r`n'issdi [aw=r`n'wtresp] if (r`n'sayret == 1 | r`n'sayret == 3) & (s`n'sayret == . | s`n'sayret == 1 | s`n'sayret == 3), detail

di "INCOME FROM SOCIAL SECURITY RETIREMENT IN WAVE `n' "
summ r`n'isret [aw=r`n'wtresp] if (r`n'sayret == 1 | r`n'sayret == 3) & (s`n'sayret == . | s`n'sayret == 1 | s`n'sayret == 3), detail

di "CHECK SPOUSES INCOME FROM EARNINGS, PENSION, ANNUNITIES, SSDI, SSI, ETC."
summ s`n'ipena [aw=r`n'wtresp] if (r`n'sayret == 1 | r`n'sayret == 3) & (s`n'sayret == . | s`n'sayret == 1 | s`n'sayret == 3), detail
summ s`n'iearn [aw=r`n'wtresp] if (r`n'sayret == 1 | r`n'sayret == 3) & (s`n'sayret == . | s`n'sayret == 1 | s`n'sayret == 3), detail
summ s`n'issdi [aw=r`n'wtresp] if (r`n'sayret == 1 | r`n'sayret == 3) & (s`n'sayret == . | s`n'sayret == 1 | s`n'sayret == 3), detail
summ s`n'isret [aw=r`n'wtresp] if (r`n'sayret == 1 | r`n'sayret == 3) & (s`n'sayret == . | s`n'sayret == 1 | s`n'sayret == 3), detail

}
** END LOOP


/**
 NOTE: CHOOSE $5000 cut-off based on results above and use self-reported retirement status

 In order to create our "desired sample" we will need to reshape the
data from "wide" to "long".  This means that there should be one
record for each person-wave.  Once we have created this panel data set
then we can impose our retirement restrictions.
**/

/**
 BAD CODE!!
  old code that imposed restrictions before panel was created
  should impose retirement restrictions AFTER creating panel data set
 BAD CODE!!	
forvalues n = 1/7 {
  drop if r`n'iearn > 5000 & (r`n'sayret == 1 | r`n'sayret == 3)
  drop if s`n'iearn > 5000 & (s`n'sayret == 1 | s`n'sayret == 3)
  count
}
 **/










/**
 CREATE PANEL DATA SET BY RESHAPING DATA SET

 This code creates our "long" panel data set by taking each person
record and creating a person-year record for each wave/year in the
data set.
**/


** create demographic variables
** (these variables not change across waves)
** (other *static* demographic variables can be added here)
gen isblack = raracem == 2
gen isother = raracem == 2
gen isfemale= ragender== 2

/**
   raedyrs - respondent education (in years)
   raeduc  - 1 high-school dropout
             2 GED
             3 hsg
             4 some college
             5 college and above
**/
/**
 re-create ged, hsg, smc, clg+ (hsd is omitted category and "other"
**/
gen educ_ged = (raeduc == 2)
gen educ_hsg = (raeduc == 3)
gen educ_smc = (raeduc == 4)
gen educ_clg = (raeduc == 5)


/**
 whether health limits work
 **/
tab r7hlthlm, missing
tab s7hlthlm, missing
replace r7hlthlm = 1 if r7hlthlm == .y
replace s7hlthlm = 1 if s7hlthlm == .y
gen r1toilta = .
gen s1toilta = .
gen r1phonea = .
gen s1phonea = .
gen r1moneya = .
gen s1moneya = .
gen r1medsa  = .
gen s1medsa  = .
gen r1shopa  = .
gen s1shopa  = .
gen r1mealsa = .
gen s1mealsa = .


gen r1nhmliv = .
gen r2nhmliv = .
gen s1nhmliv = .
gen s2nhmliv = .


*
* atotf - total non-housing financial wealth
* atotb - total wealth (including secondary residence)
* aira  - IRA/Keogh
*
local hvars = "itot hhres icap iothr atotf aira atota"
foreach hvar of local hvars {
  di "renaming `hvar' to rX`hvar' and sX`hvar' ..."
  forvalues n = 1/7 {
   rename h`n'`hvar' r`n'`hvar'
   gen    s`n'`hvar' = r`n'`hvar'
  }
}

forvalues n = 1/7 {
 gen r`n'hhidpn = s`n'hhidpn
 gen r`n'cohort = hacohort
 gen s`n'cohort = hacohort
}


** "vars" is a string which contains all of the variables
** we want to transfer to panel data set.  simply add variables
** to this string and re-run rand.do to add them to the panel
** data set

** EXAMPLE:  I just added "whappy" below to get r1happy-r8happy and s1happy-s8happy in panel

local vars = ""

 ** cesd index, wave status, weight, householid id, self-reported retirement status, current age in years
local vars = " " + "`vars'" + " hhidpn cohort wtresp sayret lbrf retemp agey_b" 

 ** income variables: pension, capital inc, earnings, ssdi, ss retirement, unemp comp, other gov't transfers
 **  NOTE: icap is HOUSEHOLD capital income.  needs to be included later
local vars = " " + "`vars'" + " ipena iearn issdi isret iunwc igxfr icap iothr"

 ** insurance variables (starting with higov above): 
 **              gov plan, medicare, medicaid, champus/va, resp employer plan, spouse employer plan
 **              employer plan covers retirees, other insurance, long-term care insurance (page ~820)

 **
 ** (SEPERATE VARIABLE SINCE MAX STRING LENGTH IN STATA IS 254!!!)
 **
 ** other time-varying variables go here, too: subjective health, health limits work, ADLs
local vars_ins = " higov govmr govmd govva covr covs covrt hiothp hiltc shlt hlthlm itot hhres atotf aira atota cesd iwstat whappy enlife fsad flone going sleepr effort depres"
local adls = " walkra dressa batha eata beda toilta"
local iadls = " mapa phonea moneya medsa shopa mealsa"
local ofls  = " walksa walk1a sita chaira climsa clim1a stoopa dimea armsa pusha"
local vars_ins2 = " `adls' `iadls' `ofls' nhmliv nrsnit"

 ** preventive-health measures: cholesterol tests, flu shot, breast self-exam, mammogram, pap smear, prostate test
local vars2 = " cholst flusht breast mammog papsm prost"

 ** dieseases (see above)
local vars = " " + "`vars'" + " hibpe diabe cancre lunge hearte stroke psyche arthre back"

 ** these are time-invariant variables that should be kept in data set
local otherKeepVariables = " isblack isother isfemale raedyrs rabdate educ_*  "

 ** these strings are used to iterate over the variables we are creating in the panel data set
local keepstring   = subinstr(" `vars' `vars2'", " ", " *", .)
local keepstring_ins  = subinstr(" `vars_ins'", " ", " *", .)
local keepstring_ins2 = subinstr(" `vars_ins2'", " ", " *", .)

local respstring   = subinstr(" `vars' `vars2'", " ", " r", .)
local spousestring = subinstr(" `vars' `vars2'", " ", " s", .)
local respstring_ins   = subinstr(" `vars_ins'", " ", " r", .)
local spousestring_ins = subinstr(" `vars_ins'", " ", " s", .)
local respstring_ins2   = subinstr(" `vars_ins2'", " ", " r", .)
local spousestring_ins2 = subinstr(" `vars_ins2'", " ", " s", .)
local respstring_ins3   = "rseatBelts mcareHMO pension_dc"

di "vars: `vars' .."
di "keep: `keepstring' ..."
di "keep: `keepstring_ins' ..."
di "resp: `respstring' ..."

keep hhidpn `keepstring' `keepstring_ins' `keepstring_ins2' `otherKeepVariables' rseatBelts* mcareHMO* pension_dc*


foreach p of local vars {
 di " doing p:`p' ..."
 forvalues n = 1/7 {
  *di " doing n:`n' ..."
  *di "changing (r|s)`n'`p' to (r|s)`p'`n' ..."
    rename r`n'`p' r`p'`n'
    rename s`n'`p' s`p'`n'
 }
}
foreach p of local vars_ins {
 di " doing p:`p' ..."
 forvalues n = 1/7 {
  *di " doing n:`n' ..."
  *di "changing (r|s)`n'`p' to (r|s)`p'`n' ..."
    rename r`n'`p' r`p'`n'
    rename s`n'`p' s`p'`n'
 }
}
foreach p of local vars_ins2 {
 di " doing p:`p' ..."
 forvalues n = 1/7 {
  *di " doing n:`n' ..."
  *di "changing (r|s)`n'`p' to (r|s)`p'`n' ..."
    rename r`n'`p' r`p'`n'
    rename s`n'`p' s`p'`n'
 }
}

** (preventive-health measures are here because they are only in waves 3-7)
foreach p of local vars2 {
 di " doing p:`p' ..."
 forvalues n = 3/7 {
  *di " doing n:`n' ..."
  *di "changing (r|s)`n'`p' to (r|s)`p'`n' ..."
    rename r`n'`p' r`p'`n'
    rename s`n'`p' s`p'`n'
 }
}


** UNCOMMENT TO DROP ALL SPOUSE DATA
** drop s*

**
** RESHAPE DATA TO CREATE PANEL DATA SET
**  NOTE: preventive health measures only defined in waves 3-7
** 


memory
reshape long `respstring' `respstring_ins3' `spousestring' `respstring_ins' `spousestring_ins'  `respstring_ins2' `spousestring_ins2', i(hhidpn) j(wave)
memory

tab wave

** SAVE PANEL DATA FILE
saveold rand_panel.dta, replace


exit





